% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CoDaFunctions.R
\name{invScaledLogit}
\alias{invScaledLogit}
\title{Inverse ilr transformation using a scaled logit}
\usage{
invScaledLogit(z, constSumValue = 1)
}
\arguments{
\item{z}{An ilr coordinate, corresponding to a two-part
composition. Argument z may
be either a scalar or a vector.}

\item{constSumValue}{Sum of the composition.}
}
\value{
A scalar (the concentration) is returned.
}
\description{
Frequently compositional data comprises just two parts (that is,
the data pertain to a two dimensional simplex),
but only one value of the two parts is specified.
For example, such data might be a titanium concentration.

After transformation to isometric log-ratio (ilr)
coordinates (using function scaledLogit, for
example), the two-part composition has just one ilr coordinate.
Although the ilr coordinate could be back transformed to a concentration
using functions CalcContrastMatrix and TransIlr2Comp, it is
requires a lot of unnecessary computation and coding. For such cases,
the ilr coordinate can be back transformed using a inverse scaled logit,
which gives exactly the equivalent result. That is, it gives one value of
a two-part composition.
}
\details{
The inverse ilr transformation is derived from equation 5 in the
reference.
}
\examples{
(constSumValue <- 1.0e6)
(z <- c(-8.589791, -8.373150, -8.645279))
invScaledLogit(z, constSumValue)

}
\references{
Filzmoser, P., Hron, K., and Reimann, C., 2009, Univariate statistical
analysis of enironmental (compositional) data -- Problems and possibilities:
Science of the Total Environment, 407, 6100-6108.
}
